#
# spec file for package waffle
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _majorVersion 1
%define _minorVersion 0
%define libname lib%{name}-%{_majorVersion}-%{_minorVersion}
Name:           waffle
Version:        1.7.0
Release:        bp155.3.11
Summary:        C library defering selection of GL API and window system until runtime
License:        BSD-2-Clause
Group:          Development/Libraries/X11
URL:            https://people.freedesktop.org/~chadversary/waffle/index.html
Source0:        https://gitlab.freedesktop.org/mesa/waffle/-/raw/website/files/release/%{name}-%{version}/%{name}-%{version}.tar.xz
Source1:        https://gitlab.freedesktop.org/mesa/waffle/-/raw/website/files/release/%{name}-%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
Patch0:         https://gitlab.freedesktop.org/mesa/waffle/-/merge_requests/106.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(wayland-client) >= 1.10
BuildRequires:  pkgconfig(wayland-egl) >= 9.1
BuildRequires:  pkgconfig(wayland-protocols) >= 1.12
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)

%description
Waffle is a C library that allows deferring the selection of GL API
and window system until runtime. For example, on Linux, Waffle enables
an application to select X11/EGL with an OpenGL 3.3 core profile, Wayland
with OpenGL ES2, and other window system / API combinations.

Waffle's immediate goal is to enable Piglit, Mesa's OpenGL test suite, to test
multiple GL flavors.

%package -n %{libname}
Summary:        C library defering selection of GL API and window system until runtime
Group:          System/Libraries
Requires:       %{name}

%description -n %{libname}
Waffle is a C library that allows deferring the selection of GL API
and window system until runtime. For example, on Linux, Waffle enables
an application to select X11/EGL with an OpenGL 3.3 core profile, Wayland
with OpenGL ES2, and other window system / API combinations.

Waffle's immediate goal is to enable Piglit, Mesa's OpenGL test suite, to test
multiple GL flavors.

%package devel
Summary:        Libraries, includes and more to develop Waffle applications
Group:          Development/Libraries/X11
Requires:       %{libname} = %{version}

%description devel
Devel files for the waffle C library. Libraries, includes and more to
develop Waffle applications.

%prep
%autosetup -p1

%build
%cmake \
  -Dwaffle_has_glx=1 \
  -Dwaffle_has_gbm=1 \
  -Dwaffle_has_x11_egl=1 \
  -Dwaffle_build_tests=1 \
  -DCMAKE_INSTALL_DOCDIR=%{_docdir}/waffle-%{_majorVersion}
%cmake_build

%install
%cmake_install

%check
%ctest

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%dir %{_docdir}/waffle-%{_majorVersion}
%{_docdir}/waffle-%{_majorVersion}/*.txt
%{_docdir}/waffle-%{_majorVersion}/README.md
%dir %{_docdir}/waffle-%{_majorVersion}/release-notes
%{_docdir}/waffle-%{_majorVersion}/release-notes/*.txt
%{_docdir}/waffle-%{_majorVersion}/release-notes/waffle-1.6.*.md
%{_bindir}/wflinfo
%{_datadir}/bash-completion/completions/wflinfo

%files -n %{libname}
%{_libdir}/libwaffle-1.so.*

%files devel
%{_libdir}/libwaffle-1.so
%dir %{_docdir}/waffle-%{_majorVersion}/examples
%{_docdir}/waffle-%{_majorVersion}/examples/*
%dir %{_includedir}/waffle-%{_majorVersion}
%{_includedir}/waffle-%{_majorVersion}/*.h
%{_libdir}/pkgconfig/waffle-%{_majorVersion}.pc
%{_libdir}/cmake/Waffle

%changelog
* Fri Jan 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 106.patch: wayland: fix build against version 1.20.
* Mon Mar  8 2021 Stefan Dirsch <sndirsch@suse.com>
- Update to release 1.7.0
  * wayland: Support for the xdg-shell protocol.
  * surfaceless: Implement window resize
  * GLX/WGL: Behave correctly in the presence of ARB_create_context
  * tests: Rework and extend test suite
  * cmake: Bump requirement to 2.8.12
  * man: Spelling and associated fixes.
  * GBM: Pass valid arguments to gbm_surface_create_with_modifiers
  * apple: Build fixes
* Thu Feb 25 2021 Stefan Dirsch <sndirsch@suse.com>
- bugfix release 1.6.3 (changes since 1.6.1)
  * docs: Add waffle 1.6.3 release notes
  * docs: Add waffle 1.6.2 release notes
  * meson: Fix meson build if bash-completion not found
  * meson: always install bash-completion file
  * meson: do not replace datadir for bash completion
  * wflinfo: use glGetStringi() only when available
  * gitlab-ci: update to latest ci-template
  * apple: hide GL deprecation warnings
  * tests/gl_basic_test: fix SURFACELESS_EGL only build
  * gbm: don't pass invalid arguments to gbm_surface_create_with_modifiers
  * cmocka: don't require librt, when it's not unavailable
* Tue Jan 19 2021 Martin Pluskal <mpluskal@suse.com>
- Use current cmake macros
- Specify minimal build dependencies as required by upstream
* Thu Apr  2 2020 Stefan Dirsch <sndirsch@suse.com>
- bugfix release 1.6.1
  * wflinfo: Correctly install the bash completion file
  * GLX/WGL: Handle ARB_create_context appropriatelly
  * Wayland: Build fix for -fno-common, default with GCC10
  * Surfaceless: Implement window_resize
- added  tests to cover above issues
- addressing the -fno-common build issue, required us to bump the
  wayland-client requirement to v1.10
* Tue Jun 11 2019 Stefan Dirsch <sndirsch@suse.com>
- version 1.6.0
  * nacl support in cmake
  * a shiny new meson build system
  * json output from wflinfo
  * EGL/GBM modifiers support
  * Out of the box FreeBSD support when using meson
  * Also included are a number of behind the scenes changes from
    Emil, in particular a massive refactoring/improvement of the
    unit tests.
- no longer package LICENSE in every subpackage: instead let library
  package require base package
- improve description of devel package
* Wed Jun 13 2018 mpluskal@suse.com
- Install license
* Sun Nov 19 2017 mpluskal@suse.com
- Add gpg signature
- Build and run functional tests
- Use more of cmake macros
- Small cleanup with spec-cleaner
* Tue Jan 24 2017 jengelh@inai.de
- Trim fillers from description; set RPM groups properly.
- Heed shared library packaging guideline: libwaffle-1-0 must
  contain only the library.
* Mon Dec 12 2016 mimi.vx@gmail.com
- use standard cmake macros
- spec-cleaned
- add support for wayland
* Thu Jul  7 2016 msrb@suse.com
- update to version 1.5.2
* Thu Apr 11 2013 oholecek@suse.cz
- update to version 1.2.2
* Thu Nov 22 2012 oholecek@suse.com
- version 1.2.1
* Mon Nov 19 2012 oholecek@suse.com
- initial package
